@@ -1,53 +1,59 @@
-( cd opt/kde/share/doc/HTML/nl/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kdm ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kig ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/amor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/amor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/karm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/karm ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kate ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/ksysguard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/ksysguard ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/crashes ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/crashes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/babel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/babel ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmag ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kodo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kodo ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/korn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/korn ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kalzium ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/khangman ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/khangman ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kpercentage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kpercentage ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kandy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kandy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/kfind ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kfind ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmail ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/kuick ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kuick ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/klipper ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/klipper ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kuser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kuser ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmousetool ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/webarchiver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/webarchiver ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kontact ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konsole ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/domtreeviewer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/smbmounter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/smbmounter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kverbos ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/imgallery ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/imgallery ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/khtmlsettings ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/validators ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/validators ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf qpl-license.html )
@@ -84,6 +90,8 @@
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doxygen.css )
@@ -98,12 +106,16 @@
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/nl/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/nl/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license.html )
@@ -134,6 +146,8 @@
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/spellchecking ; rm -rf common )
@@ -152,6 +166,8 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/filetypes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/clock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/email ; rm -rf common )
@@ -174,6 +190,8 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/crypto ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/energy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/netpref ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlaunch ; rm -rf common )
@@ -202,34 +220,56 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/konq-plugins ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kbruch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/keduca ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/keduca ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kgamma ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmessedwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmouth ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmplot ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/knotes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kpilot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kpilot ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/uachanger ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/uachanger ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/mediaplayer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kstars ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ktouch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ktouch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/kfouleggs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kaphorism ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/dirfilter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/dirfilter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/klettres ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/klettres ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kteatime ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kteatime ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmathtool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmathtool ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pci ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/usb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/scsi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/blockdevices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/xserver ; rm -rf common )
@@ -240,11 +280,21 @@
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konqueror ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konqueror ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/korganizer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/korganizer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
